@@ -1,4 +1,5 @@
 #include "config.h"
+
 #include "xyzsh/xyzsh.h"
 #include <string.h>
 #include <stdio.h>
@@ -432,94 +433,6 @@ static void sCommand_copy_deeply_stack(sCommand* dest, sCommand* src)
     dest->mRedirectsFileNamesRuntime = NULL;
 }
 
-static void sCommand_copy_deeply_malloc(sCommand* dest, sCommand* src)
-{
-    dest->mKind = src->mKind;
-
-    dest->mArgs = MALLOC(sizeof(char*)*src->mArgsSize);
-    dest->mArgsFlags = MALLOC(sizeof(int)*src->mArgsSize);
-    dest->mArgsNum = src->mArgsNum;
-    dest->mArgsSize = src->mArgsSize;
-
-    int i;
-    for(i=0; i<src->mArgsNum; i++) {
-        dest->mArgs[i] = STRDUP(src->mArgs[i]);
-        dest->mArgsFlags[i] = src->mArgsFlags[i];
-    }
-    dest->mArgs[i] = NULL;
-
-    dest->mEnvs = MALLOC(sizeof(sEnv)*src->mEnvsSize);
-    for(i=0; i<src->mEnvsNum; i++) {
-        dest->mEnvs[i].mKind = src->mEnvs[i].mKind;
-
-        if(src->mEnvs[i].mKind == kEnv) {
-            dest->mEnvs[i].mName = STRDUP(src->mEnvs[i].mName);
-            dest->mEnvs[i].mKey = STRDUP(src->mEnvs[i].mKey);
-            dest->mEnvs[i].mKeyEnv = src->mEnvs[i].mKeyEnv;
-            dest->mEnvs[i].mDoubleDollar = src->mEnvs[i].mDoubleDollar;
-        }
-        else {
-            dest->mEnvs[i].mBlock = block_clone_malloc(src->mEnvs[i].mBlock);
-            dest->mEnvs[i].mDoubleDollar = src->mEnvs[i].mDoubleDollar;
-            dest->mEnvs[i].mLineField = src->mEnvs[i].mLineField;
-        }
-    }
-    dest->mEnvsNum = src->mEnvsNum;
-    dest->mEnvsSize = src->mEnvsSize;
-
-/*
-    dest->mArgsRuntime = MALLOC(sizeof(char*)*src->mArgsSizeRuntime);
-    dest->mArgsNumRuntime = src->mArgsNumRuntime;
-    dest->mArgsSizeRuntime = src->mArgsSizeRuntime;
-
-    for(i=0; i<src->mArgsNumRuntime; i++) {
-        dest->mArgsRuntime[i] = STRDUP(src->mArgsRuntime[i]);
-    }
-    dest->mArgsRuntime[i] = NULL;
-*/
-    dest->mArgsRuntime = MALLOC(sizeof(char*)*3);
-    dest->mArgsSizeRuntime = 3;
-    dest->mArgsNumRuntime = 0;
-
-    dest->mBlocks = MALLOC(sizeof(sObject*)*src->mBlocksSize);
-    dest->mBlocksNum = src->mBlocksNum;
-    dest->mBlocksSize = src->mBlocksSize;
-
-    for(i=0; i<src->mBlocksNum; i++) {
-        dest->mBlocks[i] = block_clone_malloc(src->mBlocks[i]);
-    }
-
-    dest->mRedirectsFileNames = MALLOC(sizeof(char*)*src->mRedirectsSize);
-    for(i=0; i<src->mRedirectsNum; i++) {
-        dest->mRedirectsFileNames[i] = STRDUP(src->mRedirectsFileNames[i]);
-    }
-    dest->mRedirects = MALLOC(sizeof(int)*src->mRedirectsSize);
-    for(i=0; i<src->mRedirectsNum; i++) {
-        dest->mRedirects[i] = src->mRedirects[i];
-    }
-    dest->mRedirectsSize = src->mRedirectsSize;
-    dest->mRedirectsNum = src->mRedirectsNum;
-
-/*
-    memcpy(dest->mOptions, src->mOptions, sizeof(option_hash_it)*XYZSH_OPTION_MAX);
-
-    for(i=0; i<XYZSH_OPTION_MAX; i++) {
-        if(src->mOptions[i].mKey) { dest->mOptions[i].mKey = STRDUP(src->mOptions[i].mKey); }
-        if(src->mOptions[i].mArg) { dest->mOptions[i].mArg = STRDUP(src->mOptions[i].mArg); }
-    }
-*/
-    memset(dest->mOptions, 0, sizeof(option_hash_it)*XYZSH_OPTION_MAX);
-
-    if(src->mMessagesNum > 0) {
-        for(i=0; i<src->mMessagesNum; i++) {
-            dest->mMessages[i] = STRDUP(src->mMessages[i]);
-        }
-        dest->mMessagesNum = src->mMessagesNum;
-    }
-
-    dest->mRedirectsFileNamesRuntime = NULL;
-}
-
 void sCommand_delete(sCommand* self)
 {
     int i;
@@ -568,59 +481,6 @@ void sCommand_delete(sCommand* self)
     }
 }
 
-void sCommand_delete_malloc(sCommand* self)
-{
-    int i;
-    for(i=0; i<self->mArgsNum; i++) {
-        FREE(self->mArgs[i]);
-    }
-    FREE(self->mArgs);
-    FREE(self->mArgsFlags);
-    for(i=0; i<self->mArgsNumRuntime; i++) {
-        FREE(self->mArgsRuntime[i]);
-    }
-    FREE(self->mArgsRuntime);
-
-    for(i=0; i<self->mEnvsNum; i++) {
-        if(self->mEnvs[i].mKind == kEnv) {
-            FREE(self->mEnvs[i].mName);
-            FREE(self->mEnvs[i].mKey);
-        }
-        else {
-            block_delete_malloc(self->mEnvs[i].mBlock);
-        }
-    }
-    if(self->mEnvs) FREE(self->mEnvs);
-
-    for(i=0; i<XYZSH_OPTION_MAX; i++) {
-        if(self->mOptions[i].mKey) { FREE(self->mOptions[i].mKey); }
-        if(self->mOptions[i].mArg) { FREE(self->mOptions[i].mArg); }
-    }
-    for(i=0; i<self->mMessagesNum; i++) {
-        FREE(self->mMessages[i]);
-    }
-
-    for(i=0; i<self->mBlocksNum; i++) {
-        block_delete_malloc(self->mBlocks[i]);
-    }
-    if(self->mBlocks) FREE(self->mBlocks);
-
-    if(self->mRedirectsFileNames) {
-        for(i=0; i<self->mRedirectsNum; i++) {
-            FREE(self->mRedirectsFileNames[i]);
-        }
-        FREE(self->mRedirectsFileNames);
-    }
-    if(self->mRedirects) FREE(self->mRedirects);
-
-    if(self->mRedirectsFileNamesRuntime) {
-        for(i=0; i<self->mRedirectsNum; i++) {
-            FREE(self->mRedirectsFileNamesRuntime[i]);
-        }
-        FREE(self->mRedirectsFileNamesRuntime);
-    }
-}
-
 void sCommand_view(sCommand* self)
 {
     printf("mArgsSize: %d\n", self->mArgsSize);
@@ -746,26 +606,6 @@ static void sStatment_copy_deeply_stack(sStatment* dest, sStatment* source)
     dest->mFlags = source->mFlags;
 }
 
-static void sStatment_copy_deeply_malloc(sStatment* dest, sStatment* source)
-{
-    dest->mCommandsNum = source->mCommandsNum;
-
-    int i;
-    for(i=0; i<source->mCommandsNum; i++) {
-        sCommand_copy_deeply_malloc(dest->mCommands + i, source->mCommands + i);
-    }
-
-    if(source->mFName) {
-        dest->mFName = STRDUP(source->mFName);
-    }
-    else {
-        dest->mFName = NULL;
-    }
-    dest->mLine = source->mLine;
-
-    dest->mFlags = source->mFlags;
-}
-
 void sStatment_delete(sStatment* self)
 {
     int i;
@@ -775,15 +615,6 @@ void sStatment_delete(sStatment* self)
     if(self->mFName) FREE(self->mFName);
 }
 
-void sStatment_delete_malloc(sStatment* self)
-{
-    int i;
-    for(i=0; i<self->mCommandsNum; i++) {
-        sCommand_delete_malloc(self->mCommands + i);
-    }
-    if(self->mFName) FREE(self->mFName);
-}
-
 void sStatment_view(sStatment* self)
 {
     printf("mFlags ");
@@ -817,34 +648,6 @@ void sStatment_view(sStatment* self)
     }
 }
 
-#ifdef MDEBUG
-sObject* block_new_debug_from_malloc(const char* fname, int line, const char* func_name)
-{
-   sObject* self = (sObject*)CheckMemLeak_Malloc(sizeof(sObject), fname, line, func_name);
-   
-   SBLOCK(self).mStatments = MALLOC(sizeof(sStatment)*1);
-   memset(SBLOCK(self).mStatments, 0, sizeof(sStatment)*1);
-   SBLOCK(self).mStatmentsNum = 0;
-   SBLOCK(self).mStatmentsSize = 1;
-   SBLOCK(self).mSource = NULL;
-
-   return self;
-}
-#else
-sObject* block_new_from_malloc()
-{
-   sObject* self = MALLOC(sizeof(sObject));
-   
-   SBLOCK(self).mStatments = MALLOC(sizeof(sStatment)*1);
-   memset(SBLOCK(self).mStatments, 0, sizeof(sStatment)*1);
-   SBLOCK(self).mStatmentsNum = 0;
-   SBLOCK(self).mStatmentsSize = 1;
-   SBLOCK(self).mSource = NULL;
-
-   return self;
-}
-#endif
-
 sObject* block_new_from_gc(BOOL user_object)
 {
    sObject* self = gc_get_free_object(T_BLOCK, user_object);
@@ -885,33 +688,6 @@ sObject* block_clone_gc(sObject* source, int type, BOOL user_object)
     return self;
 }
 
-sObject* block_clone_malloc(sObject* source)
-{
-    sObject* self = MALLOC(sizeof(sObject));
-
-    const int statments_size = SBLOCK(source).mStatmentsSize;
-    
-    SBLOCK(self).mStatments = MALLOC(sizeof(sStatment)*statments_size);
-    memset(SBLOCK(self).mStatments, 0, sizeof(sStatment)*statments_size);
-    SBLOCK(self).mStatmentsNum = SBLOCK(source).mStatmentsNum;
-    SBLOCK(self).mStatmentsSize = statments_size;
-    if(SBLOCK(source).mSource) {
-        SBLOCK(self).mSource = STRDUP(SBLOCK(source).mSource);
-    }
-    else {
-        SBLOCK(self).mSource = NULL;
-    }
-    SBLOCK(self).mCompletionFlags = SBLOCK(source).mCompletionFlags;
-
-    /// copy contents of all statments
-    int i;
-    for(i=0; i<SBLOCK(source).mStatmentsNum; i++) {
-        sStatment_copy_deeply_malloc(SBLOCK(self).mStatments + i, SBLOCK(source).mStatments + i);
-    }
-
-    return self;
-}
-
 sObject* block_clone_stack(sObject* source, int type)
 {
     sObject* self = stack_get_free_object(type);
@@ -974,19 +750,6 @@ void block_delete_stack(sObject* self)
     if(SBLOCK(self).mSource) FREE(SBLOCK(self).mSource);
 }
 
-void block_delete_malloc(sObject* self)
-{
-    int i;
-    for(i=0; i<SBLOCK(self).mStatmentsNum; i++) {
-        sStatment_delete_malloc(SBLOCK(self).mStatments + i);
-    }
-    FREE(SBLOCK(self).mStatments);
-
-    if(SBLOCK(self).mSource) FREE(SBLOCK(self).mSource);
-
-    FREE(self);
-}
-
 //////////////////////////////////////////////////////////////////////////
 // some functions
 /////////////////////////////////////////////////////////////////////////
@@ -1407,6 +1170,7 @@ BOOL sCommand_expand_env(sCommand* command, sObject* fun, sObject* nextin, sObje
                     char** tails;
                     if(!expand_glob(expanded_str, ALLOC &head, ALLOC &tails, command, runinfo->mSName, runinfo->mSLine))
                     {
+                        FREE(expanded_str);
                         return FALSE;
                     }
                     sCommand_add_arg_to_command2(command, MANAGED head);
@@ -1417,6 +1181,8 @@ BOOL sCommand_expand_env(sCommand* command, sObject* fun, sObject* nextin, sObje
                     }
                     FREE(tails);
                 }
+
+                FREE(expanded_str);
             }
             else {
                 char* expanded_str;
@@ -1498,6 +1264,8 @@ BOOL sCommand_expand_env_redirect(sCommand* command, sObject* nextin, sRunInfo*
                         p++;
                     }
                     FREE(tails);
+
+                    FREE(expanded_str);
                 }
                 else {
                     command->mRedirectsFileNamesRuntime[i] = MANAGED expanded_str;
