@@ -220,7 +220,7 @@ BOOL cmd_lines(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         lf = kBel;
     }
 
-    if(command->mArgsNumRuntime > 1 && command->mBlocksNum == command->mArgsNumRuntime-1 && runinfo->mFilter) {
+    if(command->mArgsNumRuntime > 1 && command->mBlocksNum <= command->mArgsNumRuntime-1 && runinfo->mFilter) {
         if(SFD(nextin).fdbuf.mBufLen == 0) {
             runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
         }
@@ -286,13 +286,23 @@ BOOL cmd_lines(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                                 return FALSE;
                             }
 
-                            int rcode = 0;
-                            if(!run(command->mBlocks[i-1], nextin2, nextout, &rcode, runinfo->mCurrentObject, runinfo->mRunningObject)) {
+                            if(i-1 < command->mBlocksNum) {
+                                int rcode = 0;
+                                if(!run(command->mBlocks[i-1], nextin2, nextout, &rcode, runinfo->mCurrentObject, runinfo->mRunningObject)) {
+                                    runinfo->mRCode = rcode;
+                                    return FALSE;
+                                }
                                 runinfo->mRCode = rcode;
-                                return FALSE;
                             }
-
-                            runinfo->mRCode = rcode;
+                            else {
+                                if(!fd_write(nextout, SFD(nextin2).fdbuf.mBuf, SFD(nextin2).fdbuf.mBufLen))
+                                {
+                                    err_msg("interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                                    runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
+                                    return FALSE;
+                                }
+                                runinfo->mRCode = 0;
+                            }
                         }
                     }
                     else {
@@ -309,13 +319,25 @@ BOOL cmd_lines(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                                 return FALSE;
                             }
 
-                            int rcode = 0;
-                            if(!run(command->mBlocks[i-1], nextin2, nextout, &rcode, runinfo->mCurrentObject, runinfo->mRunningObject)) {
-                                runinfo->mRCode = rcode;
-                                return FALSE;
-                            }
+                            if(i-1 < command->mBlocksNum) {
+                                int rcode = 0;
+                                if(!run(command->mBlocks[i-1], nextin2, nextout, &rcode, runinfo->mCurrentObject, runinfo->mRunningObject)) {
+                                    runinfo->mRCode = rcode;
+                                    return FALSE;
+                                }
 
-                            runinfo->mRCode = rcode;
+                                runinfo->mRCode = rcode;
+                            }
+                            else {
+                                if(!fd_write(nextout, SFD(nextin2).fdbuf.mBuf, SFD(nextin2).fdbuf.mBufLen))
+                                {
+                                    err_msg("interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                                    runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
+                                    return FALSE;
+                                }
+
+                                runinfo->mRCode = 0;
+                            }
                         }
                     }
                 }
@@ -340,13 +362,25 @@ BOOL cmd_lines(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                         return FALSE;
                     }
 
-                    int rcode = 0;
-                    if(!run(command->mBlocks[i-1], nextin2, nextout, &rcode, runinfo->mCurrentObject, runinfo->mRunningObject)) {
-                        runinfo->mRCode = rcode;
-                        return FALSE;
-                    }
+                    if(i-1 < command->mBlocksNum) {
+                        int rcode = 0;
+                        if(!run(command->mBlocks[i-1], nextin2, nextout, &rcode, runinfo->mCurrentObject, runinfo->mRunningObject)) {
+                            runinfo->mRCode = rcode;
+                            return FALSE;
+                        }
 
-                    runinfo->mRCode = rcode;
+                        runinfo->mRCode = rcode;
+                    }
+                    else {
+                        if(!fd_write(nextout, SFD(nextin2).fdbuf.mBuf, SFD(nextin2).fdbuf.mBufLen))
+                        {
+                            err_msg("interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                            runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
+                            return FALSE;
+                        }
+
+                        runinfo->mRCode = 0;
+                    }
                 }
             }
         }
