@@ -486,7 +486,7 @@ BOOL cmd_msleep(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     sCommand* command = runinfo->mCommand;
 
     if(command->mArgsNumRuntime == 2) {
-        ///  ///
+        /// Ω–Œœ ///
         char c [] = {'.', 'o', 'O'};
         int n = atoi(command->mArgsRuntime[1]);
         int i;
@@ -815,7 +815,7 @@ BOOL cmd_prompt(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     sCommand* command = runinfo->mCommand;
     if(command->mBlocksNum == 1) {
         gPrompt = block_clone_gc(command->mBlocks[0], T_BLOCK, FALSE);
-        uobject_put(gxyzshObject, "_prompt", gPrompt);
+        uobject_put(gXyzshObject, "_prompt", gPrompt);
         runinfo->mRCode = 0;
     }
 
