@@ -11,7 +11,7 @@ static sObject** gPool;
 static sObject* gFreeObjectHead;
 sObject* gRootObject;
 sObject* gCompletionObject;
-sObject* gxyzshObject;
+sObject* gXyzshObject;
 sObject* gCurrentObject;
 sObject* gMemChecker;
 sObject* gStackFrames;
@@ -203,21 +203,20 @@ void gc_init(int pool_size)
 
     uobject_put(gRootObject, "compl", gCompletionObject);
 
-    gxyzshObject = UOBJECT_NEW_GC(8, NULL, "xyzsh", FALSE);
+    gXyzshObject = UOBJECT_NEW_GC(8, NULL, "xyzsh", FALSE);
     gStackFrames = VECTOR_NEW_GC(8, FALSE);
-    uobject_put(gxyzshObject, "_stackframes", gStackFrames);
+    uobject_put(gXyzshObject, "_stackframes", gStackFrames);
 }
 
 void gc_final()
 {
     /// sweep all user objects ///
     uobject_clear(gRootObject);
-    uobject_clear(gxyzshObject);
+    uobject_clear(gXyzshObject);
     if(gAppType == kATConsoleApp) {
         printf("sweeped %d objects...\n", gc_sweep());
     }
 
-    /// delete container ///
     int i;
     for(i=0; i<gPoolSize; i++) {
         sObject* p = gPool[i];
@@ -232,42 +231,6 @@ void gc_final()
     FREE(gPool);
 }
 
-/*
-static int mark_objects_in_pipe(sObject* current_pipe)
-{
-    assert(TYPE(current_pipe) == T_FD);
-
-    int count = 0;
-
-    enum eLineField lf;
-    if(fd_guess_lf(current_pipe, &lf)) {
-        fd_split(current_pipe, lf);
-    }
-    else {
-        fd_split(current_pipe, kLF);
-    }
-
-    int i;
-    for(i=0; i<vector_count(SFD(current_pipe).fdbuf.mLines); i++) {
-        char* line = vector_item(SFD(current_pipe).fdbuf.mLines, i);
-        void* mem = (void*)(unsigned long)strtoll(line, NULL, 16);
-
-        int type = memchecker_item(gMemChecker, mem);
-
-        if(type >= 0) {
-            sObject* obj = mem;
-
-            obj->mFlg |= GC_MARK;
-            count++;
-
-            count += object_gc_children_mark(obj);
-        }
-    }
-
-    return count;
-}
-*/
-
 static int mark()
 {
     int i;
@@ -284,8 +247,8 @@ static int mark()
     gRootObject->mFlg |= GC_MARK;
     int count = uobject_gc_children_mark(gRootObject);
 
-    gxyzshObject->mFlg |= GC_MARK;
-    count += uobject_gc_children_mark(gxyzshObject);
+    gXyzshObject->mFlg |= GC_MARK;
+    count += uobject_gc_children_mark(gXyzshObject);
 
     return count;
 }
