@@ -1,7 +1,6 @@
 #include "config.h"
 #include <stdio.h>
 #include <string.h>
-#include <assert.h>
 #include "xyzsh/xyzsh.h"
 
 hash_it* hash_it_new(char* key, void* item, hash_it* coll_it, hash_it* next_it, sObject* hash) 
@@ -93,7 +92,8 @@ sObject* hash_new_from_stack(int size)
 
 void hash_delete_gc(sObject* self)
 {
-   assert(TYPE(self) == T_HASH);
+   ASSERT(TYPE(self) == T_HASH);
+
    hash_it* it = SHASH(self).mEntryIt;
 
    while(it) {
@@ -107,7 +107,8 @@ void hash_delete_gc(sObject* self)
 
 void hash_delete_stack(sObject* self)
 {
-   assert(TYPE(self) == T_HASH);
+   ASSERT(TYPE(self) == T_HASH);
+
    hash_it* it = SHASH(self).mEntryIt;
 
    while(it) {
@@ -121,7 +122,8 @@ void hash_delete_stack(sObject* self)
 
 void hash_delete_malloc(sObject* self)
 {
-   assert(TYPE(self) == T_HASH);
+   ASSERT(TYPE(self) == T_HASH);
+
    hash_it* it = SHASH(self).mEntryIt;
 
    while(it) {
@@ -137,7 +139,7 @@ void hash_delete_malloc(sObject* self)
 
 static unsigned int get_hash_value(sObject* self, char* key)
 {
-   assert(TYPE(self) == T_HASH);
+   ASSERT(TYPE(self) == T_HASH);
 
    unsigned int i = 0;
    while(*key) {
@@ -150,7 +152,8 @@ static unsigned int get_hash_value(sObject* self, char* key)
 
 static void resize(sObject* self) 
 {
-    assert(TYPE(self) == T_HASH);
+   ASSERT(TYPE(self) == T_HASH);
+
     const int table_size = SHASH(self).mTableSize;
 
     SHASH(self).mTableSize *= 5;
@@ -172,7 +175,7 @@ static void resize(sObject* self)
 
 void hash_put(sObject* self, char* key, void* item)
 {
-    assert(TYPE(self) == T_HASH);
+   ASSERT(TYPE(self) == T_HASH);
 
     if(SHASH(self).mCounter >= SHASH(self).mTableSize) {
         resize(self);
@@ -199,7 +202,8 @@ void hash_put(sObject* self, char* key, void* item)
 
 static void erase_from_list(sObject* self, hash_it* rit)
 {
-   assert(TYPE(self) == T_HASH);
+   ASSERT(TYPE(self) == T_HASH);
+
    if(rit == SHASH(self).mEntryIt) {
       SHASH(self).mEntryIt = rit->mNextIt;
    }
@@ -219,7 +223,8 @@ static void erase_from_list(sObject* self, hash_it* rit)
 
 BOOL hash_erase(sObject* self, char* key)
 {
-   assert(TYPE(self) == T_HASH);
+   ASSERT(TYPE(self) == T_HASH);
+
    const unsigned int hash_value = get_hash_value(self, key);
    hash_it* it = SHASH(self).mTable[hash_value];
    
@@ -260,7 +265,8 @@ BOOL hash_erase(sObject* self, char* key)
 
 void hash_clear(sObject* self)
 {
-   assert(TYPE(self) == T_HASH);
+   ASSERT(TYPE(self) == T_HASH);
+
    int i;
    int max;
    hash_it* it = SHASH(self).mEntryIt;
@@ -279,7 +285,8 @@ void hash_clear(sObject* self)
 
 void hash_replace(sObject* self, char* key, void* item)
 {
-   assert(TYPE(self) == T_HASH);
+   ASSERT(TYPE(self) == T_HASH);
+
    hash_it* it = SHASH(self).mTable[get_hash_value(self, key)];
 
    if(it) {
@@ -296,7 +303,7 @@ void hash_replace(sObject* self, char* key, void* item)
 
 void hash_show(sObject* self, char* fname)
 {
-   assert(TYPE(self) == T_HASH);
+   ASSERT(TYPE(self) == T_HASH);
 
    char tmp[8096];
    int i;
@@ -333,7 +340,7 @@ void hash_show(sObject* self, char* fname)
 
 void* hash_item(sObject* self, char* key)
 {
-   assert(TYPE(self) == T_HASH);
+   ASSERT(TYPE(self) == T_HASH);
 
    hash_it* it = SHASH(self).mTable[ get_hash_value(self, key) ];
 
@@ -347,7 +354,7 @@ void* hash_item(sObject* self, char* key)
 
 void* hash_item_addr(sObject* self, char* key)
 {
-   assert(TYPE(self) == T_HASH);
+   ASSERT(TYPE(self) == T_HASH);
 
    hash_it* it = SHASH(self).mTable[ get_hash_value(self, key) ];
    while(it) {
@@ -360,7 +367,7 @@ void* hash_item_addr(sObject* self, char* key)
    
 char* hash_key(sObject* self, void* item)
 {
-   assert(TYPE(self) == T_HASH);
+   ASSERT(TYPE(self) == T_HASH);
 
    hash_it* it = SHASH(self).mEntryIt;
 
@@ -374,14 +381,14 @@ char* hash_key(sObject* self, void* item)
 
 int hash_count(sObject* self)
 {
-   assert(TYPE(self) == T_HASH);
+   ASSERT(TYPE(self) == T_HASH);
 
    return SHASH(self).mCounter;
 }   
 
 hash_it* hash_loop_begin(sObject* self) 
 { 
-    assert(TYPE(self) == T_HASH); 
+   ASSERT(TYPE(self) == T_HASH);
 
     return SHASH(self).mEntryIt; 
 }
@@ -403,7 +410,7 @@ hash_it* hash_loop_next(hash_it* it)
 
 int hash_gc_children_mark(sObject* self)
 {
-    assert(TYPE(self) == T_HASH);
+   ASSERT(TYPE(self) == T_HASH);
 
     int count = 0;
 
