@@ -63,7 +63,7 @@ static char* prompt()
     xyzsh_set_signal();
 
     sObject* fun = FUN_NEW_STACK(NULL);
-    sObject* stackframe = UOBJECT_NEW_GC(8, gxyzshObject, "_stackframe", FALSE);
+    sObject* stackframe = UOBJECT_NEW_GC(8, gXyzshObject, "_stackframe", FALSE);
     vector_add(gStackFrames, stackframe);
     //uobject_init(stackframe);
     SFUN(fun).mLocalObjects = stackframe;
@@ -109,7 +109,7 @@ BOOL xyzsh_run(int* rcode, sObject* block, char* source_name, fXyzshJobDone xyzs
     xyzsh_set_signal();
 
     sObject* fun = FUN_NEW_STACK(NULL);
-    sObject* stackframe = UOBJECT_NEW_GC(8, gxyzshObject, "_stackframe", FALSE);
+    sObject* stackframe = UOBJECT_NEW_GC(8, gXyzshObject, "_stackframe", FALSE);
     vector_add(gStackFrames, stackframe);
     //uobject_init(stackframe);
     SFUN(fun).mLocalObjects = stackframe;
@@ -269,7 +269,7 @@ BOOL xyzsh_readline_interface_onetime(int* rcode, char* cmdline, int cursor_poin
             xyzsh_set_signal();
 
             sObject* fun = FUN_NEW_STACK(NULL);
-            sObject* stackframe = UOBJECT_NEW_GC(8, gxyzshObject, "_stackframe", FALSE);
+            sObject* stackframe = UOBJECT_NEW_GC(8, gXyzshObject, "_stackframe", FALSE);
             vector_add(gStackFrames, stackframe);
             //uobject_init(stackframe);
             SFUN(fun).mLocalObjects = stackframe;
@@ -429,7 +429,7 @@ void xyzsh_readline_interface(char* cmdline, int cursor_point, char** argv, int
                 xyzsh_set_signal();
 
                 sObject* fun = FUN_NEW_STACK(NULL);
-                sObject* stackframe = UOBJECT_NEW_GC(8, gxyzshObject, "_stackframe", FALSE);
+                sObject* stackframe = UOBJECT_NEW_GC(8, gXyzshObject, "_stackframe", FALSE);
                 vector_add(gStackFrames, stackframe);
                 //uobject_init(stackframe);
                 SFUN(fun).mLocalObjects = stackframe;
@@ -539,7 +539,7 @@ void xyzsh_opt_c(char* cmd, char** argv, int argc)
         xyzsh_set_signal_optc();
 
         sObject* fun = FUN_NEW_STACK(NULL);
-        sObject* stackframe = UOBJECT_NEW_GC(8, gxyzshObject, "_stackframe", FALSE);
+        sObject* stackframe = UOBJECT_NEW_GC(8, gXyzshObject, "_stackframe", FALSE);
         vector_add(gStackFrames, stackframe);
         //uobject_init(stackframe);
         SFUN(fun).mLocalObjects = stackframe;
