@@ -570,7 +570,7 @@ char** readline_on_complete(const char* text, int start, int end)
                 sObject* nextout = FD_NEW_STACK(kFDKindBuf, 0);
 
                 sObject* fun = FUN_NEW_STACK(NULL);
-                sObject* stackframe = UOBJECT_NEW_GC(8, gxyzshObject, "_stackframe", FALSE);
+                sObject* stackframe = UOBJECT_NEW_GC(8, gXyzshObject, "_stackframe", FALSE);
                 vector_add(gStackFrames, stackframe);
                 //uobject_init(stackframe);
                 SFUN(fun).mLocalObjects = stackframe;
@@ -722,7 +722,7 @@ BOOL cmd_completion(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                         stack_start_stack();
 
                         sObject* fun = FUN_NEW_STACK(NULL);
-                        sObject* stackframe = UOBJECT_NEW_GC(8, gxyzshObject, "_stackframe", FALSE);
+                        sObject* stackframe = UOBJECT_NEW_GC(8, gXyzshObject, "_stackframe", FALSE);
                         vector_add(gStackFrames, stackframe);
                         //uobject_init(stackframe);
                         SFUN(fun).mLocalObjects = stackframe;
@@ -877,7 +877,7 @@ static int readline_macro(int count, int key)
         xyzsh_set_signal();
 
         sObject* fun = FUN_NEW_STACK(NULL);
-        sObject* stackframe = UOBJECT_NEW_GC(8, gxyzshObject, "_stackframe", FALSE);
+        sObject* stackframe = UOBJECT_NEW_GC(8, gXyzshObject, "_stackframe", FALSE);
         vector_add(gStackFrames, stackframe);
         //uobject_init(stackframe);
         SFUN(fun).mLocalObjects = stackframe;
