@@ -25,7 +25,9 @@ sObject* gStderr;
 
 sObject* gGlobalPipe;
 
-sObject* gObjectsInPipe;
+static sObject* gObjectsInPipe;
+
+static sObject* gRunningObjects;
 
 BOOL add_object_to_objects_in_pipe(sObject* object, sRunInfo* runinfo, sCommand* command)
 {
@@ -53,7 +55,7 @@ void run_init(enum eAppType app_type)
     gStdout = FD_NEW_STACK(kFDKindBuf, 0);
     gStderr = FD_NEW_STACK(kFDKindBuf, 0);
     gJobs = VECTOR_NEW_GC(16, FALSE);
-    uobject_put(gxyzshObject, "_jobs", gJobs);
+    uobject_put(gXyzshObject, "_jobs", gJobs);
 
     xyzsh_job_done = NULL;
 
@@ -63,347 +65,16 @@ void run_init(enum eAppType app_type)
     gGlobalPipe = FD_NEW_STACK(kFDKindBuf, 0);
 
     gObjectsInPipe = VECTOR_NEW_GC(10, FALSE);
-    uobject_put(gxyzshObject, "_objects_in_pipe", gObjectsInPipe);
+    uobject_put(gXyzshObject, "_objects_in_pipe", gObjectsInPipe);
+
+    gRunningObjects = VECTOR_NEW_GC(10, FALSE);
+    uobject_put(gXyzshObject, "_running_block", gRunningObjects);
 }
 
 void run_final()
 {
 }
 
-sObject* fd_new_from_stack(int kind, int fd)
-{
-    sObject* self = stack_get_free_object(T_FD);
-
-    SFD(self).mKind = kind;
-
-    if(kind == kFDKindFD) {
-        SFD(self).fd.mFD = fd;
-    }
-    else {
-        SFD(self).fdbuf.mBuf = MALLOC(1024);
-        SFD(self).fdbuf.mBuf[0] = 0;
-
-        SFD(self).fdbuf.mBufSize = 1024;
-        SFD(self).fdbuf.mBufLen = 0;
-
-        SFD(self).fdbuf.mLines = VECTOR_NEW_MALLOC(32);
-        SFD(self).fdbuf.mReadedLineNumber = 0;
-    }
-
-    return self;
-}
-
-void fd_delete_stack(sObject* self)
-{
-    if(SFD(self).mKind == kFDKindBuf) {
-        sObject* v = SFD(self).fdbuf.mLines;
-        int i;
-        for(i=0; i<vector_count(v); i++) {
-            FREE(vector_item(v, i));
-        }
-        vector_delete_malloc(SFD(self).fdbuf.mLines);
-
-        FREE(SFD(self).fdbuf.mBuf);
-    }
-}
-
-// TRUE: Success
-// FALSE: signal interrupt. set RCODE_SIGNAL_INTERRUPT on rcode and err message
-BOOL bufsiz_write(int fd, char* buf, int buf_size)
-{
-    char* p = buf;
-    while(p - buf < buf_size) {
-        int size;
-        if(buf_size - (p - buf) < BUFSIZ) {
-            size = buf_size - (p-buf);
-        }
-        else {
-            size = BUFSIZ;
-        }
-
-        if(write(fd, p, size) < 0) {
-            if(errno == EINTR) {
-                while(!gxyzshSigInt);
-                gxyzshSigInt = FALSE;
-                return FALSE;
-            }
-            return FALSE;
-        }
-
-        if(gxyzshSigInt) {
-            gxyzshSigInt = FALSE;
-            return FALSE;
-        }
-
-        p+=size;
-    }
-
-    return TRUE;
-}
-
-BOOL fd_guess_lf(sObject* self, enum eLineField* lf)
-{
-    *lf = -1;
-    char* p = SFD(self).fdbuf.mBuf;
-
-    while(*p) {
-        if(*p == '\a') {
-            *lf = kBel;
-            return TRUE;
-        }
-        else {
-            p++;
-        }
-    }
-
-    if(*lf == -1) {
-        p = SFD(self).fdbuf.mBuf;
-
-        while(*p) {
-            if(*p == '\r' && *(p+1) == '\n') {
-                *lf = kCRLF;
-                return TRUE;
-            }
-            else {
-                p++;
-            }
-        }
-    }
-
-    if(*lf == -1) {
-        p = SFD(self).fdbuf.mBuf;
-
-        while(*p) {
-            if(*p == '\r') {
-                *lf = kCR;
-                return TRUE;
-            }
-            else {
-                p++;
-            }
-        }
-    }
-
-    if(*lf == -1) {
-        p = SFD(self).fdbuf.mBuf;
-
-        while(*p) {
-            if(*p == '\n') {
-                *lf = kLF;
-                return TRUE;
-            }
-            else {
-                p++;
-            }
-        }
-    }
-
-    return FALSE;
-}
-
-void fd_split(sObject* self, enum eLineField lf)
-{
-    assert(TYPE(self) == T_FD && SFD(self).mKind == kFDKindBuf);
-
-    sObject* v = SFD(self).fdbuf.mLines;
-
-    if(SFD(self).fdbuf.mLinesLineField != lf) {
-        int i;
-        for(i=0; i<vector_count(v); i++) {
-            FREE(vector_item(v, i));
-        }
-        vector_clear(v);
-        SFD(self).fdbuf.mReadedLineNumber = 0;
-    }
-
-    if(vector_count(v) == 0) {
-        char* p = SFD(self).fdbuf.mBuf;
-        char* new_line = p;
-        if(lf == kCRLF) {
-            while(1) {
-                if(*p == '\r' && *(p+1) == '\n') {
-                    p+=2;
-                    const int size = p - new_line;
-                    char* line = MALLOC(size + 1);
-                    memcpy(line, new_line, size);
-                    line[size] = 0;
-                    vector_add(v, line);
-                    new_line = p;
-                }
-                else if(p - SFD(self).fdbuf.mBuf >= SFD(self).fdbuf.mBufLen) {
-                    const int size = p - new_line;
-                    if(size > 0) {
-                        char* line = MALLOC(size + 1 + 2);
-                        memcpy(line, new_line, size);
-                        line[size] = '\r';
-                        line[size+1] = '\n';
-                        line[size+2] = 0;
-                        vector_add(v, line);
-                    }
-                    break;
-                }
-                else {
-                    p++;
-                }
-            }
-        }
-        else {
-            char split_char;
-            if(lf == kLF) {
-                split_char = '\n';
-            }
-            else if(lf == kCR) {
-                split_char = '\r';
-            }
-            else {
-                split_char = '\a';
-            }
-
-            while(1) {
-                if(*p == split_char) {
-                    const int size = p - new_line + 1;
-                    char* line = MALLOC(size + 1);
-                    memcpy(line, new_line, size);
-                    line[size] = 0;
-                    vector_add(v, line);
-                    p++;
-                    new_line = p;
-                }
-                else if(p - SFD(self).fdbuf.mBuf >= SFD(self).fdbuf.mBufLen) {
-                    const int size = p - new_line;
-                    if(size > 0) {
-                        char* line = MALLOC(size + 1 + 1);
-                        memcpy(line, new_line, size);
-                        line[size] = split_char;
-                        line[size+1] = 0;
-                        vector_add(v, line);
-                    }
-                    break;
-                }
-                else {
-                    p++;
-                }
-            }
-        }
-
-        SFD(self).fdbuf.mLinesLineField = lf;
-    }
-}
-
-// TRUE: Success
-// FALSE: signal interrupt
-static BOOL memcpy_buf(char* dest, char* src, size_t size)
-{
-    char* p = dest;
-    char* p2 = src;
-    while(1) {
-        if(gxyzshSigInt) {
-            gxyzshSigInt = FALSE;
-            return FALSE;
-        }
-        if(size - (p - dest) < BUFSIZ) {
-            memcpy(p, p2, size - (p-dest));
-            break;
-        }
-        else {
-            memcpy(p, p2, BUFSIZ);
-            p+=BUFSIZ;
-            p2+=BUFSIZ;
-        }
-    }
-
-    return TRUE;
-}
-
-void fd_clear(sObject* self)
-{
-    assert(TYPE(self) == T_FD);
-
-    if(SFD(self).mKind == kFDKindBuf) {
-        SFD(self).fdbuf.mBufLen = 0;
-        SFD(self).fdbuf.mBuf[0] = 0;
-
-        int i;
-        for(i=0; i<vector_count(SFD(self).fdbuf.mLines); i++) {
-            FREE(vector_item(SFD(self).fdbuf.mLines, i));
-        }
-        vector_clear(SFD(self).fdbuf.mLines);
-        SFD(self).fdbuf.mReadedLineNumber = 0;
-    }
-}
-
-// TRUE: Success
-// FALSE: signal interrupt. set RCODE_SIGNAL_INTERRUPT on rcode and err message
-BOOL fd_write(sObject* self, char* str, int len)
-{
-    if(SFD(self).mKind == kFDKindFD) {
-        if(write(SFD(self).fd.mFD, str, len) < 0) {
-            return FALSE;
-        }
-    }
-    else {
-        if((SFD(self).fdbuf.mBufLen+len+1) >= SFD(self).fdbuf.mBufSize) {
-            int new_size = (SFD(self).fdbuf.mBufSize + len+1) * 1.8;
-
-            SFD(self).fdbuf.mBuf = REALLOC(SFD(self).fdbuf.mBuf, new_size);
-            SFD(self).fdbuf.mBufSize = new_size;
-        }
-
-
-        if(!memcpy_buf(SFD(self).fdbuf.mBuf + SFD(self).fdbuf.mBufLen, str, len)) {
-            return FALSE;
-        }
-        SFD(self).fdbuf.mBufLen += len;
-        SFD(self).fdbuf.mBuf[SFD(self).fdbuf.mBufLen] = 0;
-    }
-
-    return TRUE;
-}
-
-// TRUE: Success
-// FALSE: signal interrupt. set RCODE_SIGNAL_INTERRUPT on rcode and err message
-BOOL fd_writec(sObject* self, char c)
-{
-    if(SFD(self).mKind == kFDKindFD) {
-        if(write(SFD(self).fd.mFD, &c, 1) < 0) {
-            return FALSE;
-        }
-    }
-    else {
-        if((SFD(self).fdbuf.mBufLen) >= SFD(self).fdbuf.mBufSize) {
-            int new_size = (SFD(self).fdbuf.mBufSize) * 1.8;
-            SFD(self).fdbuf.mBuf = REALLOC(SFD(self).fdbuf.mBuf, new_size);
-            SFD(self).fdbuf.mBufSize = new_size;
-        }
-
-        SFD(self).fdbuf.mBuf[SFD(self).fdbuf.mBufLen++] = c;
-        SFD(self).fdbuf.mBuf[SFD(self).fdbuf.mBufLen] = 0;
-
-        if(gxyzshSigInt) {
-            gxyzshSigInt = FALSE;
-            return FALSE;
-        }
-    }
-
-    return TRUE;
-}
-
-// TRUE: Success
-// FALSE: signal interrupt. set RCODE_SIGNAL_INTERRUPT on rcode and err message
-BOOL fd_flash(sObject* self, int fd)
-{
-    if(SFD(self).mKind == kFDKindBuf) {
-        if(!bufsiz_write(fd, SFD(self).fdbuf.mBuf, SFD(self).fdbuf.mBufLen)) {
-            return FALSE;
-        }
-
-        SFD(self).fdbuf.mBufLen = 0;
-        SFD(self).fdbuf.mBuf[0] = 0;
-    }
-
-    return TRUE;
-}
-
 sObject* job_new_from_gc(char* name, pid_t pgroup, struct termios tty)
 {
     sObject* self = gc_get_free_object(T_JOB, FALSE);
@@ -426,9 +97,9 @@ static BOOL nextout_reader(sObject* nextout, int* pipeoutfds, sRunInfo* runinfo,
 {
     char buf[BUFSIZ+1];
     while(1) {
-        if(gxyzshSigInt) {
+        if(gXyzshSigInt) {
             err_msg("signal interrupt1", runinfo->mSName, runinfo->mSLine, program);
-            gxyzshSigInt = FALSE;
+            gXyzshSigInt = FALSE;
             runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
             return FALSE;
         }
@@ -910,7 +581,7 @@ BOOL run_function(sObject* fun, sObject* nextin, sObject* nextout, sRunInfo* run
     sRunInfo* runinfo2 = SFUN(fun).mRunInfo;
     SFUN(fun).mRunInfo = runinfo;
 
-    sObject* stackframe = UOBJECT_NEW_GC(8, gxyzshObject, "_stackframe", FALSE);
+    sObject* stackframe = UOBJECT_NEW_GC(8, gXyzshObject, "_stackframe", FALSE);
     vector_add(gStackFrames, stackframe);
     //uobject_init(stackframe);
     SFUN(fun).mLocalObjects = stackframe;
@@ -1130,6 +801,17 @@ static BOOL run_object(sObject* object, sObject* nextin, sObject* nextout, sRunI
             }
             break;
 
+        case T_EXTOBJ: { 
+            if(SEXTOBJ(object).mMainFun) {
+                if(!SEXTOBJ(object)
+                      .mMainFun(SEXTOBJ(object).mObject, nextin, nextout, runinfo))
+                {
+                    return FALSE;
+                }   
+            }
+            }
+            break;
+
         default: {
             char buf[BUFSIZ];
             sCommand* command = runinfo->mCommand;
@@ -1393,7 +1075,7 @@ static BOOL statment_tree(sStatment* statment, sObject* pipein, sObject* pipeout
                     reciever = object;
                     object = uobject_item(object, command->mArgs[0]);
 
-                    if(object == gInherit) {
+                    if(object == gInheritObject) {
                         sObject* running_object = runinfo->mRunningObject;
 
                         if(runinfo->mRunningObject) {
@@ -1459,7 +1141,7 @@ static BOOL statment_tree(sStatment* statment, sObject* pipein, sObject* pipeout
                 sObject* reciever = current_object;
                 sObject* object = access_object(command->mArgs[0], &reciever, runinfo->mRunningObject);
 
-                if(object == gInherit) {
+                if(object == gInheritObject) {
                     sObject* running_object = runinfo->mRunningObject;
 
                     if(runinfo->mRunningObject) {
@@ -1546,6 +1228,9 @@ static BOOL statment_tree(sStatment* statment, sObject* pipein, sObject* pipeout
 
 BOOL run(sObject* block, sObject* pipein, sObject* pipeout, int* rcode, sObject* current_object, sObject* running_object)
 {
+    vector_add(gRunningObjects, running_object); // for marking on gc
+    vector_add(gRunningObjects, block); // for marking on gc
+
     static unsigned int n = 0;
     static int nest_level = 0;
     nest_level++;
@@ -1559,6 +1244,8 @@ BOOL run(sObject* block, sObject* pipein, sObject* pipeout, int* rcode, sObject*
         }
         nest_level--;
 
+        (void)vector_pop_back(gRunningObjects);
+        (void)vector_pop_back(gRunningObjects);
         return FALSE;
     }
 
@@ -1594,6 +1281,8 @@ BOOL run(sObject* block, sObject* pipein, sObject* pipeout, int* rcode, sObject*
 
             if(!(n++ % 32)) (void)gc_sweep();
 
+            (void)vector_pop_back(gRunningObjects);
+            (void)vector_pop_back(gRunningObjects);
             return FALSE;
         }
 
@@ -1612,6 +1301,8 @@ BOOL run(sObject* block, sObject* pipein, sObject* pipeout, int* rcode, sObject*
                     vector_clear(gObjectsInPipe);
                 }
                 if(!(n++ % 32)) (void)gc_sweep();
+                (void)vector_pop_back(gRunningObjects);
+                (void)vector_pop_back(gRunningObjects);
                 return FALSE;
             }
         }
@@ -1630,13 +1321,15 @@ BOOL run(sObject* block, sObject* pipein, sObject* pipeout, int* rcode, sObject*
                     vector_clear(gObjectsInPipe);
                 }
                 if(!(n++ % 32)) (void)gc_sweep();
+                (void)vector_pop_back(gRunningObjects);
+                (void)vector_pop_back(gRunningObjects);
                 return FALSE;
             }
         }
 
         /// the end of statment ///
-        if(gxyzshSigUser) {
-            gxyzshSigUser = FALSE;
+        if(gXyzshSigUser) {
+            gXyzshSigUser = FALSE;
             sCommand* command = runinfo.mCommand;
             err_msg("command not found", runinfo.mSName, runinfo.mSLine, ""); //command->mArgs[0]);
             stack_end_stack();
@@ -1647,10 +1340,12 @@ BOOL run(sObject* block, sObject* pipein, sObject* pipeout, int* rcode, sObject*
                 vector_clear(gObjectsInPipe);
             }
             if(!(n++ % 32)) (void)gc_sweep();
+            (void)vector_pop_back(gRunningObjects);
+            (void)vector_pop_back(gRunningObjects);
             return FALSE;
         }
-        else if(runinfo.mRCode == 128+SIGINT || gxyzshSigInt) {
-            gxyzshSigInt = FALSE;
+        else if(runinfo.mRCode == 128+SIGINT || gXyzshSigInt) {
+            gXyzshSigInt = FALSE;
             sCommand* command = runinfo.mCommand;
             err_msg("signal interrupt15", runinfo.mSName, runinfo.mSLine, command->mArgs[0]);
             *rcode = RCODE_SIGNAL_INTERRUPT;
@@ -1662,6 +1357,8 @@ BOOL run(sObject* block, sObject* pipein, sObject* pipeout, int* rcode, sObject*
                 vector_clear(gObjectsInPipe);
             }
             if(!(n++ % 32)) (void)gc_sweep();
+            (void)vector_pop_back(gRunningObjects);
+            (void)vector_pop_back(gRunningObjects);
             return FALSE;
         }
         else if((statment->mFlags & STATMENT_OROR) && runinfo.mRCode == 0) {
@@ -1692,6 +1389,8 @@ BOOL run(sObject* block, sObject* pipein, sObject* pipeout, int* rcode, sObject*
     }
     if(!(n++ % 32)) (void)gc_sweep();
 
+    (void)vector_pop_back(gRunningObjects);
+    (void)vector_pop_back(gRunningObjects);
     return TRUE;
 }
 
@@ -1880,7 +1579,7 @@ BOOL load_file(char* fname, sObject* nextin, sObject* nextout, sRunInfo* runinfo
         FREE(buf);
 
         sObject* fun = FUN_NEW_STACK(NULL);
-        sObject* stackframe = UOBJECT_NEW_GC(8, gxyzshObject, "_stackframe", FALSE);
+        sObject* stackframe = UOBJECT_NEW_GC(8, gXyzshObject, "_stackframe", FALSE);
         vector_add(gStackFrames, stackframe);
         //uobject_init(stackframe);
         SFUN(fun).mLocalObjects = stackframe;
