@@ -2,7 +2,6 @@
 #include "xyzsh/xyzsh.h"
 #include <string.h>
 #include <stdio.h>
-#include <assert.h>
 
 static unsigned int get_uobject_value(sObject* self, char* key)
 {
@@ -97,11 +96,11 @@ sObject* uobject_new_from_stack(int size, sObject* parent, char* name)
    return self;
 }
 
-sObject* gInherit;
+sObject* gInheritObject;
 
 void uobject_root_init(sObject* self)
 {
-    assert(TYPE(self) == T_UOBJECT);
+    ASSERT(TYPE(self) == T_UOBJECT);
 
     uobject_put(self, "unset", NFUN_NEW_GC(cmd_unset, NULL, TRUE));
     sObject* readline = UOBJECT_NEW_GC(8, self, "rl", TRUE);
@@ -136,8 +135,8 @@ void uobject_root_init(sObject* self)
     uobject_put(self, "write", NFUN_NEW_GC(cmd_write, NULL, TRUE));
     uobject_put(self, "quote", NFUN_NEW_GC(cmd_quote, NULL, TRUE));
     uobject_put(self, "load", NFUN_NEW_GC(cmd_load, NULL, TRUE));
-    gInherit = NFUN_NEW_GC(cmd_inherit, NULL, TRUE);
-    uobject_put(self, "inherit", gInherit);
+    gInheritObject = NFUN_NEW_GC(cmd_inherit, NULL, TRUE);
+    uobject_put(self, "inherit", gInheritObject);
     uobject_put(self, "eval", NFUN_NEW_GC(cmd_eval, NULL, TRUE));
     uobject_put(self, "object", NFUN_NEW_GC(cmd_object, NULL, TRUE));
     uobject_put(self, "pwo", NFUN_NEW_GC(cmd_pwo, NULL, TRUE));
@@ -276,7 +275,7 @@ void uobject_root_init(sObject* self)
 
 void uobject_init(sObject* self)
 {
-    assert(TYPE(self) == T_UOBJECT);
+    ASSERT(TYPE(self) == T_UOBJECT);
 
     uobject_put(self, "run", NFUN_NEW_GC(cmd_mrun, NULL, FALSE));
     uobject_put(self, "self", self);
@@ -287,7 +286,7 @@ void uobject_init(sObject* self)
 
 void uobject_delete_gc(sObject* self)
 {
-   assert(TYPE(self) == T_UOBJECT);
+    ASSERT(TYPE(self) == T_UOBJECT);
 
    uobject_it* it = SUOBJECT(self).mEntryIt;
 
@@ -303,7 +302,7 @@ void uobject_delete_gc(sObject* self)
 
 void uobject_delete_stack(sObject* self)
 {
-   assert(TYPE(self) == T_UOBJECT);
+    ASSERT(TYPE(self) == T_UOBJECT);
 
    uobject_it* it = SUOBJECT(self).mEntryIt;
 
@@ -319,7 +318,7 @@ void uobject_delete_stack(sObject* self)
 
 int uobject_gc_children_mark(sObject* self)
 {
-    assert(TYPE(self) == T_UOBJECT);
+    ASSERT(TYPE(self) == T_UOBJECT);
 
     int count = 0;
 
@@ -342,7 +341,7 @@ int uobject_gc_children_mark(sObject* self)
 
 void uobject_put(sObject* self, char* key, void* item)
 {
-    assert(TYPE(self) == T_UOBJECT);
+    ASSERT(TYPE(self) == T_UOBJECT);
 
     if(SUOBJECT(self).mCounter >= SUOBJECT(self).mTableSize) {
         resize(self);
@@ -369,7 +368,7 @@ void uobject_put(sObject* self, char* key, void* item)
 
 void* uobject_item(sObject* self, char* key)
 {
-   assert(TYPE(self) == T_UOBJECT);
+    ASSERT(TYPE(self) == T_UOBJECT);
 
    uobject_it* it = SUOBJECT(self).mTable[ get_uobject_value(self, key) ];
 
@@ -383,7 +382,7 @@ void* uobject_item(sObject* self, char* key)
 
 void uobject_clear(sObject* self)
 {
-   assert(TYPE(self) == T_UOBJECT);
+    ASSERT(TYPE(self) == T_UOBJECT);
 
    int i;
    int max;
@@ -403,7 +402,7 @@ void uobject_clear(sObject* self)
 
 uobject_it* uobject_loop_begin(sObject* self) 
 { 
-    assert(TYPE(self) == T_UOBJECT); 
+    ASSERT(TYPE(self) == T_UOBJECT);
 
     return SUOBJECT(self).mEntryIt; 
 }
@@ -425,14 +424,15 @@ uobject_it* uobject_loop_next(uobject_it* it)
 
 int uobject_count(sObject* self)
 {
-   assert(TYPE(self) == T_UOBJECT);
+    ASSERT(TYPE(self) == T_UOBJECT);
 
    return SUOBJECT(self).mCounter;
 }
 
 static void erase_from_list(sObject* self, uobject_it* rit)
 {
-   assert(TYPE(self) == T_UOBJECT);
+    ASSERT(TYPE(self) == T_UOBJECT);
+
    if(rit == SUOBJECT(self).mEntryIt) {
       SUOBJECT(self).mEntryIt = rit->mNextIt;
    }
@@ -452,7 +452,7 @@ static void erase_from_list(sObject* self, uobject_it* rit)
 
 BOOL uobject_erase(sObject* self, char* key)
 {
-   assert(TYPE(self) == T_UOBJECT);
+    ASSERT(TYPE(self) == T_UOBJECT);
    const unsigned int hash_value = get_uobject_value(self, key);
    uobject_it* it = SUOBJECT(self).mTable[hash_value];
    
