@@ -9,10 +9,10 @@
 
 sObject* gErrMsg;
 
-volatile BOOL gxyzshSigInt;
-volatile BOOL gxyzshSigUser;
-volatile BOOL gxyzshSigTstp;
-volatile BOOL gxyzshSigCont;
+volatile BOOL gXyzshSigInt;
+volatile BOOL gXyzshSigUser;
+volatile BOOL gXyzshSigTstp;
+volatile BOOL gXyzshSigCont;
 
 sObject* gDirStack;
 
@@ -57,33 +57,6 @@ void xyzsh_read_rc_core(char* path)
     xyzsh_restore_signal_default();
 }
 
-/*
-typedef struct {
-    char* mData;
-    int mData2;
-} sTestObj;
-
-int sTestObj_markfun(sObject* self)
-{
-    return 0;
-}
-
-void sTestObj_freefun(void* self)
-{
-    sTestObj* obj = self;
-    FREE(obj->mData);
-    FREE(obj);
-}
-
-sObject* sTestObj_new(char* data, int data2)
-{
-    sTestObj* obj = MALLOC(sizeof(sTestObj));
-    obj->mData = STRDUP(data);
-    obj->mData2 = data2;
-    return EXTOBJ_NEW_GC(obj, sTestObj_markfun, sTestObj_freefun, TRUE);
-}
-*/
-
 static void xyzsh_read_rc()
 {
     char sys_rc_path[PATH_MAX];
@@ -108,14 +81,11 @@ static void xyzsh_read_rc()
     xyzsh_read_rc_core(help_rc_path);
     xyzsh_read_rc_core(completion_rc_path);
     xyzsh_read_rc_core(user_rc_path);
-
-
-//    uobject_put(gRootObject, "test", sTestObj_new("AAA", 1));
 }
 
 void xyzsh_init(enum eAppType app_type, BOOL no_runtime_script)
 {
-    setenv("XYZSH_VERSION", "1.2.7", 1);
+    setenv("XYZSH_VERSION", "1.2.8", 1);
     setenv("XYZSH_DATAROOTDIR", DATAROOTDIR, 1);
 
     setlocale(LC_ALL, "");
@@ -125,10 +95,10 @@ void xyzsh_init(enum eAppType app_type, BOOL no_runtime_script)
 
     gErrMsg = STRING_NEW_STACK("");
 
-    gxyzshSigInt = FALSE;
-    gxyzshSigUser = FALSE;
-    gxyzshSigTstp = FALSE;
-    gxyzshSigCont = FALSE;
+    gXyzshSigInt = FALSE;
+    gXyzshSigUser = FALSE;
+    gXyzshSigTstp = FALSE;
+    gXyzshSigCont = FALSE;
 
     xyzsh_set_signal_other = NULL;
 
@@ -137,7 +107,7 @@ void xyzsh_init(enum eAppType app_type, BOOL no_runtime_script)
     xyzsh_readline_init(FALSE);
 
     gDirStack = VECTOR_NEW_GC(10, FALSE);
-    uobject_put(gxyzshObject, "_dir_stack", gDirStack);
+    uobject_put(gXyzshObject, "_dir_stack", gDirStack);
 
     char* term_env = getenv("TERM");
     if(term_env != NULL && strcmp(term_env, "") != 0) {
@@ -199,7 +169,7 @@ void err_msg_adding(char* msg, char* sname, int line, char* command)
 
 void sig_int()
 {
-    gxyzshSigInt = TRUE; 
+    gXyzshSigInt = TRUE; 
 
 #ifdef MDEBUG
 fprintf(stderr, "SIGINT!!\n");
@@ -208,7 +178,7 @@ fprintf(stderr, "SIGINT!!\n");
 
 void sig_tstp()
 {
-    gxyzshSigInt = TRUE; 
+    gXyzshSigInt = TRUE; 
 #ifdef MDEBUG
 fprintf(stderr, "SIGTSTP!!\n");
 #endif
@@ -217,7 +187,7 @@ fprintf(stderr, "SIGTSTP!!\n");
 void sig_int_optc()
 {
     sigchld_block(1);
-    gxyzshSigInt = TRUE; 
+    gXyzshSigInt = TRUE; 
     //killpg(0, SIGINT);
 #ifdef MDEBUG
 //fprintf(stderr, "SIGINT!!\n");
@@ -245,7 +215,7 @@ void sig_cont_optc()
 
 void sig_user()
 {
-    gxyzshSigUser = TRUE;
+    gXyzshSigUser = TRUE;
 }
 
 void sigchld_action(int signum, siginfo_t* info, void* ctx)
