@@ -63,8 +63,25 @@ enum eCommandKind {
     kCommandMax
 };
 
-typedef void (*fFreeFun)(void*);
-typedef int (*fMarkFun)(void*);
+enum eLineField { kLF, kCRLF, kCR, kBel };
+extern enum eLineField gLineField;
+extern enum eKanjiCode gKanjiCode;
+
+enum eAppType { kATOptC, kATXApp, kATConsoleApp };
+    // Application kind
+
+extern enum eAppType gAppType;
+
+struct _sObject;
+
+extern struct _sObject* gErrMsg;               // error message
+
+extern struct _sObject* gStdin;
+extern struct _sObject* gStdout;
+extern struct _sObject* gStderr;
+
+void xyzsh_init(enum eAppType app_type, BOOL no_runtime_script);
+void xyzsh_final();
 
 typedef struct _list_it {
    void* mItem;
@@ -88,10 +105,6 @@ typedef struct _hash_it {
    struct _hash_it* mNextIt;
 } hash_it;
 
-enum eLineField { kLF, kCRLF, kCR, kBel };
-extern enum eLineField gLineField;
-extern enum eKanjiCode gKanjiCode;
-
 typedef struct {
    hash_it** mTable;
    int mTableSize;
@@ -116,15 +129,6 @@ typedef struct {
    int mCount;
 } vector_obj;
 
-/*
-typedef struct {
-   void** mTable;
-   int mTableSize;
-   
-   int mCount;
-} stackframes_obj;
-*/
-
 #define kFDKindFD 1
 #define kFDKindBuf 2
 
@@ -166,6 +170,8 @@ struct sStatment;
 #define STATMENT_CONTEXTPIPE_NUMBER 0xFFFF
 
 #define STATMENT_COMMANDS_MAX 16
+#define XYZSH_OPTION_MAX 32
+#define XYZSH_MESSAGES_MAX 8
 
 struct block_obj;
 struct _sObject;
@@ -175,9 +181,6 @@ typedef struct _option_hash_it {
     char* mArg;
 } option_hash_it;
 
-#define XYZSH_OPTION_MAX 32
-#define XYZSH_MESSAGES_MAX 8
-
 enum eEnvKind { kEnv, kEnvBlock};
 
 typedef struct {
@@ -198,7 +201,6 @@ typedef struct {
 } sEnv;
 
 #define REDIRECT_KIND 0xff
-
 #define REDIRECT_IN 0x1
 #define REDIRECT_APPEND 0x2
 #define REDIRECT_OUT 0x4
@@ -274,12 +276,11 @@ struct block_obj
 struct _sObject;
 struct _sRunInfo;
 
-typedef struct                // a function object can be treated as block_obj
+typedef struct
 {
     struct _sObject* mBlock;
 
     struct _sObject* mParent;
-//    int mParentCount;
 
     struct _sObject* mLocalObjects;
     struct _sObject* mArgBlocks;
@@ -288,19 +289,7 @@ typedef struct                // a function object can be treated as block_obj
     struct _sRunInfo* mRunInfo;
 } fun_obj;
 
-typedef struct                // a function object can be treated as block_obj
-{
-    struct _sObject* mBlock;
-
-    struct _sObject* mParent;
-//    int mParentCount;
-
-    struct _sObject* mLocalObjects;
-    struct _sObject* mArgBlocks;
-
-    option_hash_it* mOptions;
-    struct _sRunInfo* mRunInfo;
-} class_obj;
+typedef fun_obj class_obj;
 
 typedef BOOL (*fXyzshNativeFun)(struct _sObject*, struct _sObject*, struct _sRunInfo*);
 
@@ -328,7 +317,7 @@ typedef struct _uobject_it {
    struct _uobject_it* mNextIt;
 } uobject_it;
 
-typedef struct {          // a user object can be treated like a hash_obj
+typedef struct {
    uobject_it** mTable;
    int mTableSize;
 
@@ -359,13 +348,18 @@ typedef struct {
    int mCounter;
 } memchecker_obj;
 
+struct _sRunInfo;
+
 typedef int (*fExtObjMarkFun)(struct _sObject* self);
 typedef void (*fExtObjFreeFun)(void* self);
+typedef BOOL (*fExtObjMainFun)(void* self, struct _sObject* nextin, struct _sObject* nextout, struct _sRunInfo* runinfo);
 
 typedef struct {
     void* mObject;
+
     fExtObjMarkFun mMarkFun;
     fExtObjFreeFun mFreeFun;
+    fExtObjMainFun mMainFun;
 } external_obj;
 
 typedef struct {
@@ -454,8 +448,15 @@ int stack_page_size();
 #include <xyzsh/block.h>
 #include <xyzsh/curses.h>
 
-sObject* extobj_new_from_gc(void* object, fExtObjMarkFun mark_fun, fExtObjFreeFun free_fun, BOOL user_object);
-#define EXTOBJ_NEW_GC(o, o2, o3, o4) extobj_new_from_gc(o, o2, o3, o4)
+sObject* extobj_new_from_gc(void* object, fExtObjMarkFun mark_fun, fExtObjFreeFun free_fun, fExtObjMainFun main_fun, BOOL user_object);
+#define EXTOBJ_NEW_GC(o, o2, o3, o4, o5) extobj_new_from_gc(o, o2, o3, o4, o5)
+
+#define UOBJECT_NEW_GC(o, o2, o3, o4) uobject_new_from_gc(o, o2, o3, o4)
+#define UOBJECT_NEW_STACK(o, o2, o3) uobject_new_from_stack(o, o2, o3)
+
+void uobject_delete_gc(sObject* self);
+void uobject_delete_stack(sObject* self);
+int uobject_gc_children_mark(sObject* self);
 
 sObject* uobject_new_from_gc(int size, sObject* parent, char* name, BOOL user_object);
 sObject* uobject_new_from_stack(int size, sObject* object, char* name);
@@ -465,26 +466,70 @@ void uobject_root_init(sObject* self);
 void uobject_put(sObject* self, char* key, void* item);
 void* uobject_item(sObject* self, char* key);
 void uobject_clear(sObject* self);
-
 uobject_it* uobject_loop_begin(sObject* self);
 void* uobject_loop_item(uobject_it* it);
 char* uobject_loop_key(uobject_it* it);
 uobject_it* uobject_loop_next(uobject_it* it);
 int uobject_count(sObject* self);
 
-#define UOBJECT_NEW_GC(o, o2, o3, o4) uobject_new_from_gc(o, o2, o3, o4)
-#define UOBJECT_NEW_STACK(o, o2, o3) uobject_new_from_stack(o, o2, o3)
-
-void uobject_delete_gc(sObject* self);
-void uobject_delete_stack(sObject* self);
-int uobject_gc_children_mark(sObject* self);
-
 sObject* external_prog_new_from_gc(char* path, BOOL user_object);
 void external_prog_delete_gc();
 
 #define EXTPROG_NEW_GC(o, o2) external_prog_new_from_gc(o, o2)
 
-/// structure used from run, which contains run time info
+sObject* memchecker_new_from_stack(int size);
+void memchecker_delete_stack(sObject* self);
+
+#define MEMCHECKER_NEW_STACK(o) memchecker_new_from_stack(o)
+
+void memchecker_put(sObject* self, void* key, int item);
+BOOL memchecker_erase(sObject* self, void* key);
+int memchecker_item(sObject* self, void* key);
+
+sObject* completion_new_from_gc(sObject* block, BOOL user_object);
+int completion_gc_children_mark(sObject* self);
+
+#define COMPLETION_NEW_GC(o, o2) completion_new_from_gc(o, o2)
+
+sObject* nfun_new_from_gc(fXyzshNativeFun fun, sObject* parent, BOOL user_object);
+#define NFUN_NEW_GC(o, o2, o3) nfun_new_from_gc(o, o2, o3)
+int nfun_gc_children_mark(sObject* self);
+void nfun_delete_gc(sObject* self);
+BOOL nfun_put_option_with_argument(sObject* self, MANAGED char* key);
+BOOL nfun_option_with_argument_item(sObject* self, char* key);
+
+sObject* fun_new_from_gc(sObject* parent, BOOL user_object);
+#define FUN_NEW_GC(o, o2) fun_new_from_gc(o, o2)
+void fun_delete_gc(sObject* self);
+int fun_gc_children_mark(sObject* self);
+#define FUN_NEW_STACK(o) fun_new_from_stack(o)
+sObject* fun_new_from_stack(sObject* parent);
+void fun_delete_stack(sObject* self);
+BOOL fun_put_option_with_argument(sObject* self, MANAGED char* key);
+BOOL fun_option_with_argument_item(sObject* self, char* key);
+
+sObject* class_new_from_gc(sObject* parent, BOOL user_object);
+#define CLASS_NEW_GC(o, o2) class_fun_new_from_gc(o, o2)
+void class_delete_gc(sObject* self);
+void class_delete_stack(sObject* self);
+BOOL class_option_with_argument_item(sObject* self, char* key);
+BOOL class_put_option_with_argument(sObject* self, MANAGED char* key);
+int class_gc_children_mark(sObject* self);
+
+sObject* fd_new_from_stack();
+void fd_delete_stack(sObject* self);
+#define FD_NEW_STACK(kind, fd) fd_new_from_stack(kind, fd)
+BOOL fd_write(sObject* self, char* str, int size);
+
+void fd_split(sObject* self, enum eLineField lf);
+BOOL fd_guess_lf(sObject* self, enum eLineField* lf);
+
+sObject* job_new_from_gc(char* name, pid_t pgroup, struct termios tty);
+#define JOB_NEW_GC(o, o2, o3) job_new_from_gc(o, o2, o3)
+void job_delete_gc(sObject* self);
+void job_push_back_child_pid(sObject* self, pid_t pid);
+
+/// structure used from run function, which contains run time info
 typedef struct _sRunInfo {
     char* mSName;
     int mSLine;
@@ -499,18 +544,13 @@ typedef struct _sRunInfo {
     sObject* mRecieverObject;
 } sRunInfo;
 
+BOOL xyzsh_rehash(char* sname, int sline);
+
 typedef BOOL (*fInternalCommand)(sObject*, sObject*, sRunInfo*);
 
 extern fInternalCommand kInternalCommands[kInnerCommand];
 extern char * gCommandKindStrs[kCommandMax];
 
-extern sObject* gObjectsInPipe;
-
-BOOL xyzsh_rehash(char* sname, int sline);
-
-#if defined(HAVE_MIGEMO_H)
-BOOL cmd_migemo_match(sObject* nextin, sObject* nextout, sRunInfo* runinfo);
-#endif
 BOOL cmd_kanjicode(sObject* nextin, sObject* nextout, sRunInfo* runinfo);
 BOOL cmd_defined(sObject* nextin, sObject* nextout, sRunInfo* runinfo);
 BOOL cmd_funinfo(sObject* nextin, sObject* nextout, sRunInfo* runinfo);
@@ -639,38 +679,14 @@ BOOL cmd_condition_re(sObject* nextin, sObject* nextout, sRunInfo* runinfo);
 BOOL cmd_sub(sObject* nextin, sObject* nextout, sRunInfo* runinfo);
 BOOL cmd_time(sObject* nextin, sObject* nextout, sRunInfo* runinfo);
 
-enum eAppType { kATOptC, kATXApp, kATConsoleApp };
-    // Application kind
-
-extern enum eAppType gAppType;
-
-void xyzsh_init(enum eAppType app_type, BOOL no_runtime_script);
-void xyzsh_final();
-
-void run_init(enum eAppType app_type);
-void run_final();
+#if defined(HAVE_MIGEMO_H)
+BOOL cmd_migemo_match(sObject* nextin, sObject* nextout, sRunInfo* runinfo);
+#endif
 
 BOOL run(sObject* block, sObject* pipein, sObject* pipeout, int* rcode, sObject* current_object, sObject* running_object);
-BOOL xyzsh(sObject* block, int* rcode);
 
-sObject* fd_new_from_stack();
-void fd_delete_stack(sObject* self);
-#define FD_NEW_STACK(kind, fd) fd_new_from_stack(kind, fd)
-BOOL fd_write(sObject* self, char* str, int size);
-
-sObject* job_new_from_gc(char* name, pid_t pgroup, struct termios tty);
-#define JOB_NEW_GC(o, o2, o3) job_new_from_gc(o, o2, o3)
-void job_delete_gc(sObject* self);
-void job_push_back_child_pid(sObject* self, pid_t pid);
-
-extern sObject* gErrMsg;               // error message
-
-extern sObject* gStdin;
-extern sObject* gStdout;
-extern sObject* gStderr;
-
-extern volatile BOOL gxyzshSigInt;
-extern volatile BOOL gxyzshSigUser;
+extern volatile BOOL gXyzshSigInt;
+extern volatile BOOL gXyzshSigUser;
 
 void xyzsh_restore_signal_default();
 void xyzsh_set_signal();
@@ -696,9 +712,6 @@ int gc_pool_size();
 int gc_used_objects_num();
 int gc_sweep();
 
-char* xstrncpy(char* src, char* des, int size);
-char* xstrncat(char* src, char* des, int size);
-
 BOOL parse(char* p, char* sname, int* sline, sObject* block, sObject** current_object);
 
 #define RCODE_BREAK 256
@@ -714,65 +727,19 @@ void xyzsh_kill_all_jobs();
 
 extern sObject* gRootObject;
 extern sObject* gCompletionObject;
-extern sObject* gxyzshObject;
+extern sObject* gXyzshObject;
 extern sObject* gCurrentObject;
-extern sObject* gObject;      // Object class object
 extern sObject* gStackFrames;
+extern sObject* gMemChecker;
+extern sObject* gGlobalPipe;
+extern sObject* gInheritObject;
 
 BOOL bufsiz_write(int fd, char* buf, int buf_len);
 
 BOOL load_file(char* fname, sObject* nextin, sObject* nextout, sRunInfo* runinfo, char** argv, int argc);
-BOOL xyzsh_load_file(char* fname, char** argv, int argc, sObject* current_object);
-void xyzsh_opt_c(char* cmd, char** argv, int argc);
-void xyzsh_readline_interface(char* cmdline, int cursor, char** argv, int argc);
-
-void fd_split(sObject* self, enum eLineField lf);
-BOOL fd_guess_lf(sObject* self, enum eLineField* lf);
-
-void err_msg(char* msg, char* sname, int line, char* command);
-void err_msg_adding(char* msg, char* sname, int line, char* command);
-
-sObject* memchecker_new_from_stack(int size);
-void memchecker_delete_stack(sObject* self);
-
-#define MEMCHECKER_NEW_STACK(o) memchecker_new_from_stack(o)
-
-void memchecker_put(sObject* self, void* key, int item);
-BOOL memchecker_erase(sObject* self, void* key);
-int memchecker_item(sObject* self, void* key);
 
 int object_gc_children_mark(sObject* self);
 
-sObject* completion_new_from_gc(sObject* block, BOOL user_object);
-int completion_gc_children_mark(sObject* self);
-
-#define COMPLETION_NEW_GC(o, o2) completion_new_from_gc(o, o2)
-
-sObject* nfun_new_from_gc(fXyzshNativeFun fun, sObject* parent, BOOL user_object);
-#define NFUN_NEW_GC(o, o2, o3) nfun_new_from_gc(o, o2, o3)
-int nfun_gc_children_mark(sObject* self);
-void nfun_delete_gc(sObject* self);
-BOOL nfun_put_option_with_argument(sObject* self, MANAGED char* key);
-BOOL nfun_option_with_argument_item(sObject* self, char* key);
-
-sObject* fun_new_from_gc(sObject* parent, BOOL user_object);
-#define FUN_NEW_GC(o, o2) fun_new_from_gc(o, o2)
-void fun_delete_gc(sObject* self);
-int fun_gc_children_mark(sObject* self);
-#define FUN_NEW_STACK(o) fun_new_from_stack(o)
-sObject* fun_new_from_stack(sObject* parent);
-void fun_delete_stack(sObject* self);
-BOOL fun_put_option_with_argument(sObject* self, MANAGED char* key);
-BOOL fun_option_with_argument_item(sObject* self, char* key);
-
-sObject* class_new_from_gc(sObject* parent, BOOL user_object);
-#define CLASS_NEW_GC(o, o2) class_fun_new_from_gc(o, o2)
-void class_delete_gc(sObject* self);
-void class_delete_stack(sObject* self);
-BOOL class_option_with_argument_item(sObject* self, char* key);
-BOOL class_put_option_with_argument(sObject* self, MANAGED char* key);
-int class_gc_children_mark(sObject* self);
-
 BOOL sCommand_option_item(sCommand* self, char* key);
 char* sCommand_option_with_argument_item(sCommand* self, char* key);
 BOOL sCommand_put_option(sCommand* self, MANAGED char* key);
@@ -782,56 +749,58 @@ BOOL sCommand_expand_env_redirect(sCommand* command, sObject* nextin, sRunInfo*
 void sCommand_sweep_runtime_info(sCommand* command);
 void sStatment_sweep_runtime_info(sStatment* self);
 
-extern sObject* gMemChecker;
-
-extern FILE* gTest;
-
-extern sObject* gInherit;
-
-#define XYZSH_INHERIT_MAX 32
-
-sObject* access_object(char* name, sObject** current, sObject* running_object);
-sObject* access_object2(char* name, sObject* current, sObject* running_object);
-sObject* access_object3(char* name, sObject** current);
-
 BOOL run_function(sObject* fun, sObject* nextin, sObject* nextout, sRunInfo* runinfo, char** argv, int argc, sObject** blocks, int blocks_num);
 
-extern sObject* gDirStack;
-
 #define PARSER_MAGIC_NUMBER_ENV 3
 #define PARSER_MAGIC_NUMBER_OPTION 5
 
 #include <oniguruma.h>
 int get_onig_regex(regex_t** reg, sCommand* command, char* regex);
 
-extern sObject* gPrompt;
-
-extern sObject* gGlobalPipe;
-
 int readline_signal();
 void clear_matching_info_variable();
-
-BOOL xyzsh_readline_interface_onetime(int* rcode, char* cmdline, int cursor_point, char* source_name, char** argv, int argc, fXyzshJobDone xyzsh_job_done_);
-char* xyzsh_job_title(int n);
-int xyzsh_job_num();
-BOOL xyzsh_run(int* rcode, sObject* block, char* source_name, fXyzshJobDone xyzsh_job_done_, sObject* nextin, sObject* nextout, int argc, char** argv, sObject* current_object);
-
 #include <stdarg.h>
-
-void xyzsh_add_inner_command(sObject* object, char* name, fXyzshNativeFun command, int arg_num, ...);
-
-void readline_write_history();
-void readline_read_history();
 void xyzsh_read_rc_core(char* path);
 
-extern sObject* gStackFrames;
+#define XYZSH_OBJECTS_IN_PIPE_MAX 128
+
+void run_init(enum eAppType app_type);
+void run_final();
 
 #if defined(HAVE_MIGEMO_H)
 void migemo_init();
 void migemo_final();
 #endif
 
-#define XYZSH_OBJECTS_IN_PIPE_MAX 128
+extern sObject* gPrompt;
+extern sObject* gDirStack;
+
+void readline_write_history();
+void readline_read_history();
+
+char* xstrncpy(char* src, char* des, int size);
+char* xstrncat(char* src, char* des, int size);
+
+//////////////////////////////////////////////////////////////////////
+// xyzsh API
+//////////////////////////////////////////////////////////////////////
+BOOL xyzsh_load_file(char* fname, char** argv, int argc, sObject* current_object);
+void xyzsh_opt_c(char* cmd, char** argv, int argc);
+void xyzsh_readline_interface(char* cmdline, int cursor, char** argv, int argc);
+
+void xyzsh_add_inner_command(sObject* object, char* name, fXyzshNativeFun command, int arg_num, ...);
+
+BOOL xyzsh_readline_interface_onetime(int* rcode, char* cmdline, int cursor_point, char* source_name, char** argv, int argc, fXyzshJobDone xyzsh_job_done_);
+char* xyzsh_job_title(int n);
+int xyzsh_job_num();
+BOOL xyzsh_run(int* rcode, sObject* block, char* source_name, fXyzshJobDone xyzsh_job_done_, sObject* nextin, sObject* nextout, int argc, char** argv, sObject* current_object);
+
+void err_msg(char* msg, char* sname, int line, char* command);
+void err_msg_adding(char* msg, char* sname, int line, char* command);
+
+sObject* access_object(char* name, sObject** current, sObject* running_object);
+sObject* access_object2(char* name, sObject* current, sObject* running_object);
+sObject* access_object3(char* name, sObject** current);
 
 #endif
 
